@@ -1,4 +1,3 @@
-context("test-fs_perms.R")
 
 if (!is_windows()) {
 describe("as_fs_perms (POSIX)", {
@@ -35,8 +34,8 @@ describe("as_fs_perms (POSIX)", {
     expect_equal(as_fs_perms(c("rw-r--r--", "rwxrwxrwx")), new_fs_perms(c(420L, 511L)))
   })
   it("preserves the class with both subset and subset2", {
-    expect_is(as_fs_perms("777")[1], "fs_perms")
-    expect_is(as_fs_perms("777")[[1]], "fs_perms")
+    expect_s3_class(as_fs_perms("777")[1], "fs_perms")
+    expect_s3_class(as_fs_perms("777")[[1]], "fs_perms")
   })
 })
 
@@ -79,5 +78,89 @@ describe("as_fs_perms (Windows)", {
     expect_equal(as_fs_perms("rw-"), new_fs_perms(384L))
     expect_equal(as_fs_perms(c("rw-", "rwx")), new_fs_perms(c(384L, 448L)))
   })
+  it("returns 'rwx' on windows", {
+    expect_equal(as.character(as_fs_perms("777")), "rwx")
+  })
 })
 }
+
+test_that("common type of double and fs_perms is fs_perms", {
+  expect_identical(
+    vctrs::vec_ptype2(double(), fs_perms()),
+    fs_perms()[0]
+  )
+  expect_identical(
+    vctrs::vec_ptype2(fs_perms(), double()),
+    fs_perms()[0]
+  )
+})
+
+test_that("fs_perms and double are coercible", {
+  expect_identical(
+    vctrs::vec_cast(1, fs_perms()),
+    fs_perms(1)
+  )
+  expect_identical(
+    vctrs::vec_cast(fs_perms(1), double()),
+    1L
+  )
+  expect_identical(
+    vctrs::vec_cast(fs_perms(1), fs_perms()),
+    fs_perms(1)
+  )
+})
+
+test_that("can concatenate fs_perms", {
+  expect_identical(
+    vctrs::vec_c(fs_perms(1), fs_perms(2)),
+    as_fs_perms(c(1, 2))
+  )
+})
+
+test_that("common type of integer and fs_perms is fs_perms", {
+  expect_identical(
+    vctrs::vec_ptype2(integer(), fs_perms()),
+    fs_perms()[0]
+  )
+  expect_identical(
+    vctrs::vec_ptype2(fs_perms(), integer()),
+    fs_perms()[0]
+  )
+})
+
+test_that("fs_perms and integer are coercible", {
+  expect_identical(
+    vctrs::vec_cast(1L, fs_perms()),
+    fs_perms(1L)
+  )
+  expect_identical(
+    vctrs::vec_cast(fs_perms(1L), integer()),
+    1L
+  )
+})
+
+test_that("common type of character and fs_perms is fs_perms", {
+  expect_identical(
+    vctrs::vec_ptype2(character(), fs_perms()),
+    fs_perms()[0]
+  )
+  expect_identical(
+    vctrs::vec_ptype2(fs_perms(), character()),
+    fs_perms()[0]
+  )
+})
+
+test_that("fs_perms and character are coercible", {
+  expect_identical(
+    vctrs::vec_cast("777", fs_perms()),
+    fs_perms("777")
+  )
+
+  # This test only return rwx on Windows due to the less fine grained
+  # permissions, so we skip it
+  skip_on_os("windows")
+  expect_identical(
+    vctrs::vec_cast(fs_perms("777"), character()),
+    "rwxrwxrwx"
+  )
+})
